==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Архів',
	'archiver_concatener_explications' => 'Ця операція буде об’єднувати статистику візитів за статтями:',
	'archiver_concatener_ignorer' => 'Візити за останні @nb@ роки не враховуються.',
	'archiver_concatener_par_an' => 'Додаткові візити @nb@ років будуть об’єднані для кожної статті на перший день кожного року.',
	'archiver_concatener_par_mois' => 'Додаткові візити @nb@ років будуть об’єднані для кожної статті на перший день кожного місяця.',
	'archiver_conseil_sauvegarde' => 'Рекомендуємо спочатку зробити резервне копіювання бази даних.',
	'archiver_description' => 'Ця сторінка надає інструменти для очищення або архівування статистики сайту.',
	'archiver_et_nettoyer' => 'Архівувати і очистити',
	'archiver_nettoyer' => 'Очистити',
	'archiver_nettoyer_explications' => 'Видалити рядки «посилань» або «візитів» до елементів, які (більше) не існують  в базі даних.',
	'archiver_nettoyer_referers_articles' => 'Очистити посилання на статті',
	'archiver_nettoyer_visites_articles' => 'Очистити відвідування статей',
	'archiver_nombre_lignes' => 'Кількість рядків',
	'archiver_operation_longue' => 'Ця операція може зайняти багато часу, особливо при першому виконанні.',
	'archiver_operations_irreversibles' => 'Ця операція незворотня!',

	// B
	'bouton_effacer_referers' => 'Видалити тільки вхідні посилання',
	'bouton_effacer_statistiques' => 'Видалити всю статистику',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Еволюція відвідувань<br />@visites@ відвідувань',
	'icone_repartition_actuelle' => 'Перегляд поточного розподілу',
	'icone_repartition_visites' => 'Розподіл відвідувань',
	'icone_statistiques_visites' => 'Статистика',
	'info_affichier_visites_articles_plus_visites' => 'Показати відвідування для <b>найпопулярніших статей за весь час: </b>',
	'info_comment_lire_tableau' => 'Як читати цю таблицю',
	'info_forum_statistiques' => 'Статистика відвідувань сайту',
	'info_graphiques' => 'Графіки',
	'info_popularite_2' => 'популярність сайту:',
	'info_popularite_3' => 'популярність: @popularite@; відвідувань: @visites@',
	'info_popularite_5' => 'популярність:',
	'info_previsions' => 'прогноз:',
	'info_question_vignettes_referer' => 'Система може самостійно робити скріншоти головних сторінок сайтів, з яких до вас приходять відвідувачі. Якщо ви включите цю опцію, то це зображення буде виводиться поряд з посиланням на цей сайт.',
	'info_question_vignettes_referer_oui' => 'Показати скріншоти сайтів, що посилаються',
	'info_tableaux' => 'Таблиці',
	'info_visites' => 'відвідування:',
	'info_visites_plus_populaires' => 'Показати статистику для <b>найпопулярніших</b> і <b>останніх опублікованих статей</b>:',
	'info_zoom' => 'збільшити',
	'item_gerer_statistiques' => 'Управління статистикою відвідувань',

	// O
	'onglet_origine_visites' => 'Відвідувачі прийшли з',
	'onglet_repartition_debut' => 'від початку',
	'onglet_repartition_lang' => 'Розбивка за мовами',

	// R
	'resume' => 'Підсумок',

	// T
	'texte_admin_effacer_stats' => 'Ця команда видаляє всі дані, пов’язані зі статистикою відвідування сайту, в тому числі щодо популярності статей.',
	'texte_admin_effacer_toutes_stats' => 'Перша кнопка видаляє всю статистику про: відвідування, популярність та джерела переходів.',
	'texte_comment_lire_tableau' => 'Праворуч показується рівень відвідуваності статті; чорною лінією відображається прогноз відвідувань (за умови що збережеться поточна динаміка), і зеленим кольором - кількість відвідувань за день. Для більш детальної інформації наведіть мишку на цікаву для Вас дату. ',
	'texte_signification' => 'Темні штрихи представляють сукупні записи (всього підрубрик), світлі штрихи - кількість відвідувань для кожної рубрики.',
	'titre_evolution_visite' => 'Рівень відвідувань',
	'titre_liens_entrants' => 'Вхідні посилання',
	'titre_page_statistiques' => 'За рубриками',
	'titre_page_statistiques_visites' => 'Статистика відвідувань',

	// V
	'visites_journalieres' => 'Кількість відвідувачів (день)',
	'visites_mensuelles' => 'Кількість відвідувачів (місяць)'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Архів',
	'archiver_concatener_explications' => 'Ця операція буде об’єднувати статистику візитів за статтями:',
	'archiver_concatener_ignorer' => 'Візити за останні @nb@ роки не враховуються.',
	'archiver_concatener_par_an' => 'Додаткові візити @nb@ років будуть об’єднані для кожної статті на перший день кожного року.',
	'archiver_concatener_par_mois' => 'Додаткові візити @nb@ років будуть об’єднані для кожної статті на перший день кожного місяця.',
	'archiver_conseil_sauvegarde' => 'Рекомендуємо спочатку зробити резервне копіювання бази даних.',
	'archiver_description' => 'Ця сторінка надає інструменти для очищення або архівування статистики сайту.',
	'archiver_et_nettoyer' => 'Архівувати і очистити',
	'archiver_nettoyer' => 'Очистити',
	'archiver_nettoyer_explications' => 'Видалити рядки «посилань» або «візитів» до елементів, які (більше) не існують  в базі даних.',
	'archiver_nettoyer_referers_articles' => 'Очистити посилання на статті',
	'archiver_nettoyer_visites_articles' => 'Очистити відвідування статей',
	'archiver_nombre_lignes' => 'Кількість рядків',
	'archiver_operation_longue' => 'Ця операція може зайняти багато часу, особливо при першому виконанні.',
	'archiver_operations_irreversibles' => 'Ця операція незворотня!',

	// B
	'bouton_effacer_referers' => 'Видалити тільки вхідні посилання',
	'bouton_effacer_statistiques' => 'Видалити всю статистику',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Еволюція відвідувань<br />@visites@ відвідувань',
	'icone_repartition_actuelle' => 'Перегляд поточного розподілу',
	'icone_repartition_visites' => 'Розподіл відвідувань',
	'icone_statistiques_visites' => 'Статистика',
	'info_affichier_visites_articles_plus_visites' => 'Показати відвідування для <b>найпопулярніших статей за весь час: </b>',
	'info_comment_lire_tableau' => 'Як читати цю таблицю',
	'info_forum_statistiques' => 'Статистика відвідувань сайту',
	'info_graphiques' => 'Графіки',
	'info_popularite_2' => 'популярність сайту:',
	'info_popularite_3' => 'популярність: @popularite@; відвідувань: @visites@',
	'info_popularite_5' => 'популярність:',
	'info_previsions' => 'прогноз:',
	'info_question_vignettes_referer' => 'Система може самостійно робити скріншоти головних сторінок сайтів, з яких до вас приходять відвідувачі. Якщо ви включите цю опцію, то це зображення буде виводиться поряд з посиланням на цей сайт.', # MODIF
	'info_question_vignettes_referer_oui' => 'Показати скріншоти сайтів, що посилаються',
	'info_tableaux' => 'Таблиці',
	'info_visites' => 'відвідування:',
	'info_visites_plus_populaires' => 'Показати статистику для <b>найпопулярніших</b> і <b>останніх опублікованих статей</b>:',
	'info_zoom' => 'збільшити',
	'item_gerer_statistiques' => 'Управління статистикою відвідувань',

	// O
	'onglet_origine_visites' => 'Відвідувачі прийшли з',
	'onglet_repartition_debut' => 'від початку',
	'onglet_repartition_lang' => 'Розбивка за мовами',

	// R
	'resume' => 'Підсумок',

	// T
	'texte_admin_effacer_stats' => 'Ця команда видаляє всі дані, пов’язані зі статистикою відвідування сайту, в тому числі щодо популярності статей.',
	'texte_admin_effacer_toutes_stats' => 'Перша кнопка видаляє всю статистику про: відвідування, популярність та джерела переходів.',
	'texte_comment_lire_tableau' => 'Праворуч показується рівень відвідуваності статті; чорною лінією відображається прогноз відвідувань (за умови що збережеться поточна динаміка), і зеленим кольором - кількість відвідувань за день. Для більш детальної інформації наведіть мишку на цікаву для Вас дату. ',
	'texte_signification' => 'Темні штрихи представляють сукупні записи (всього підрубрик), світлі штрихи - кількість відвідувань для кожної рубрики.',
	'titre_evolution_visite' => 'Рівень відвідувань',
	'titre_liens_entrants' => 'Вхідні посилання',
	'titre_page_statistiques' => 'За рубриками',
	'titre_page_statistiques_visites' => 'Статистика відвідувань',

	// V
	'visites_journalieres' => 'Кількість відвідувачів (день)',
	'visites_mensuelles' => 'Кількість відвідувачів (місяць)'
);
